@@ -20,8 +20,8 @@ class product_manifold(basic_manifold):
         else:
             self.split_index = 1
 
-        self.dim = np.sum(self.dim_tuple)
-        self.shape = (self.dim,)
+        self.var_num = np.sum(self.dim_tuple)
+        self.shape = (self.var_num,)
 
         self.backbone = list_manifold[0].backbone
 
@@ -95,11 +95,11 @@ class product_manifold(basic_manifold):
     def Feas_eval(self, X_list):
         return np.sqrt( self.C_quad_penalty(X_list) )
 
-    def Init_point(self, Xinit_list = None):
-        if Xinit_list is None:
+    def Init_point(self, Xinit = None):
+        if Xinit is None:
             return tuple(M.Init_point() for M in self.list_manifold)
         else:
-            return tuple(M.Init_point(Xinit) for M, Xinit in zip(self.list_manifold, Xinit_list))
+            return tuple(M.Init_point(Xinit_local) for M, Xinit_local in zip(self.list_manifold, Xinit))
 
     def Post_process(self,X_list):
         
