@@ -1,6 +1,6 @@
 __all__ = [ "basic_manifold_torch","stiefel_torch", "generalized_stiefel_torch", 
 "hyperbolic_torch", "symp_stiefel_torch", "sphere_torch",
-"euclidean_torch", "oblique_torch",
+"euclidean_torch", "oblique_torch", "stiefel_range_constraint_torch", 
 "complex_basic_manifold_torch", "complex_sphere_torch", "complex_oblique_torch", "complex_stiefel_torch" ]
 
 import torch
@@ -14,6 +14,7 @@ from .symp_stiefel_torch import symp_stiefel_torch
 from .euclidean_torch import euclidean_torch
 from .oblique_torch import oblique_torch
 from .sphere_torch import sphere_torch
+from .stiefel_range_constraint_torch import stiefel_range_constraint_torch
 
 from .complex_sphere_torch import complex_sphere_torch
 from .complex_oblique_torch import complex_oblique_torch
