@@ -4,7 +4,7 @@ from typing import Any, Callable, Dict, Iterator, List, Tuple
 import torch
 from torch import Tensor
 
-from ..modules import get_quad_penalty
+from ...nn.modules.utils import get_quad_penalty
 
 __all__ = ["functional_call"]
 
